/*
 * Copyright Camunda Services GmbH and/or licensed to Camunda Services GmbH under
 * one or more contributor license agreements. See the NOTICE file distributed
 * with this work for additional information regarding copyright ownership.
 * Licensed under the Camunda License 1.0. You may not use this file
 * except in compliance with the Camunda License 1.0.
 */
package io.camunda.optimize.rest.providers;

import co.elastic.clients.elasticsearch._types.ElasticsearchException;
import io.camunda.optimize.dto.optimize.rest.ErrorResponseDto;
import io.camunda.optimize.service.LocalizationService;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.ext.ExceptionMapper;
import jakarta.ws.rs.ext.Provider;
import lombok.extern.slf4j.Slf4j;

@Provider
@Slf4j
public class ElasticsearchExceptionMapper implements ExceptionMapper<ElasticsearchException> {
  private static final String ELASTICSEARCH_ERROR_CODE = "elasticsearchError";

  private final LocalizationService localizationService;

  public ElasticsearchExceptionMapper(@Context final LocalizationService localizationService) {
    this.localizationService = localizationService;
  }

  @Override
  public Response toResponse(final ElasticsearchException esStatusException) {
    log.error("Mapping ElasticsearchStatusException", esStatusException);

    return Response.status(Response.Status.INTERNAL_SERVER_ERROR)
        .type(MediaType.APPLICATION_JSON_TYPE)
        .entity(mapToEvaluationErrorResponseDto(esStatusException))
        .build();
  }

  private ErrorResponseDto mapToEvaluationErrorResponseDto(
      final ElasticsearchException esStatusException) {
    final String errorMessage =
        localizationService.getDefaultLocaleMessageForApiErrorCode(ELASTICSEARCH_ERROR_CODE);
    final String detailedErrorMessage = esStatusException.getMessage();

    return new ErrorResponseDto(ELASTICSEARCH_ERROR_CODE, errorMessage, detailedErrorMessage);
  }
}
